/** Categories are used to group multiple services together. A service must be associated with a category in order to be exposed in the Wix Bookings UI. */
interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Category name.
     * @maxLength 500
     */
    name?: string | null;
    /**
     * @internal
     * @internal
     * @readonly
     */
    status?: StatusWithLiterals;
    /**
     * @internal
     * @internal */
    sortOrder?: number | null;
}
declare enum Status {
    /** The category was created. */
    CREATED = "CREATED",
    /** The category was deleted. */
    DELETED = "DELETED"
}
/** @enumType */
type StatusWithLiterals = Status | 'CREATED' | 'DELETED';
interface ListCategoryRequest {
    /**
     * IDs of the categories to retrieve.
     *
     * Default: All categories are retrieved.
     * @format GUID
     */
    categoryIds?: string[];
    /**
     * @internal
     * @internal */
    includeDeleted?: boolean | null;
}
interface ListCategoryResponse {
    /** Retrieved categories. */
    categories?: Category[];
}
/** An event sent every time a category entity is changed. */
interface CategoryNotification {
    category?: Category;
    event?: EventWithLiterals;
}
declare enum Event {
    /** Category was updated. */
    Updated = "Updated",
    /** Category was deleted. */
    Deleted = "Deleted",
    /** Category was created. */
    Created = "Created"
}
/** @enumType */
type EventWithLiterals = Event | 'Updated' | 'Deleted' | 'Created';
interface CreateCategoryRequest {
    /** Category to create. */
    category: Category;
}
interface CreateCategoryResponse {
    /** Created category. */
    category?: Category;
}
interface BatchCreateCategoryRequest {
    /** Categories to create. */
    categories?: Category[];
}
interface BatchCreateCategoryResponse {
    /** Created categories. */
    categories?: Category[];
}
interface UpdateCategoryRequest {
    /** Category to update. */
    category: Category;
}
interface UpdateCategoryResponse {
    /** Updated category. */
    category?: Category;
}
interface DeleteCategoryRequest {
    /**
     * ID of the category to delete.
     * @format GUID
     */
    _id: string | null;
    /**
     * Whether to delete all the services associated with the category.
     *
     * Default: `false`
     */
    deleteServices?: boolean | null;
}
interface DeleteCategoryResponse {
    /**
     * ID of the deleted category.
     * @format GUID
     */
    _id?: string | null;
}
interface BatchDeleteCategoryRequest {
    /**
     * IDs of the categories to delete.
     * @format GUID
     */
    ids?: string[] | null;
}
interface BatchDeleteCategoryResponse {
}
interface BatchUpdateCategoryRequest {
    /** List of categories to be updated. */
    categories?: Category[];
    /** Field mask of fields to update. */
    fieldMask?: string[];
}
interface BatchUpdateCategoryResponse {
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface CategoryNotificationEnvelope {
    data: CategoryNotification;
    metadata: BaseEventMetadata;
}
interface ListCategoriesOptions {
    /**
     * IDs of the categories to retrieve.
     *
     * Default: All categories are retrieved.
     * @format GUID
     */
    categoryIds?: string[];
    /** @internal */
    includeDeleted?: boolean | null;
}
interface UpdateCategory {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Category name.
     * @maxLength 500
     */
    name?: string | null;
    /**
     * @internal
     * @readonly
     */
    status?: StatusWithLiterals;
    /** @internal */
    sortOrder?: number | null;
}
interface DeleteCategoryOptions {
    /**
     * Whether to delete all the services associated with the category.
     *
     * Default: `false`
     */
    deleteServices?: boolean | null;
}

export { type BatchCreateCategoryRequest as B, type Category as C, type DeleteCategoryOptions as D, Event as E, type IdentificationData as I, type ListCategoriesOptions as L, type MessageEnvelope as M, Status as S, type UpdateCategory as U, WebhookIdentityType as W, type ListCategoryResponse as a, type UpdateCategoryResponse as b, type DeleteCategoryResponse as c, type CategoryNotificationEnvelope as d, type ListCategoryRequest as e, type CategoryNotification as f, type CreateCategoryRequest as g, type CreateCategoryResponse as h, type BatchCreateCategoryResponse as i, type UpdateCategoryRequest as j, type DeleteCategoryRequest as k, type BatchDeleteCategoryRequest as l, type BatchDeleteCategoryResponse as m, type BatchUpdateCategoryRequest as n, type BatchUpdateCategoryResponse as o, type IdentificationDataIdOneOf as p, type BaseEventMetadata as q };
